@@ -82,6 +82,7 @@ namespace Opal {
 			    account.get_authentication_username (),
 			    account.get_password (),
 			    account.is_enabled (),
+			    account.is_limited (),
 			    account.get_timeout ());
 	} else {
 
@@ -123,6 +124,10 @@ Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager,
   dialect = gmref_ptr<SIP::Dialect>(new SIP::Dialect (core, sigc::mem_fun (this, &Opal::Sip::EndPoint::send_message)));
   chat_core->add_dialect (dialect);
 
+  bank->account_added.connect (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_bank_updated));
+  bank->account_removed.connect (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_bank_updated));
+  bank->account_updated.connect (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_bank_updated));
+
   /* Timeouts */
   SetAckTimeout (PTimeInterval (0, 32));
   SetPduCleanUpTimeout (PTimeInterval (0, 1));
@@ -177,9 +182,8 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
 {
   bool populated = false;
 
-
   std::list<std::string> uris;
-  std::list<std::string> accounts;
+  std::list<std::string> accounts_list;
 
   if (!(uri.find ("sip:") == 0 || uri.find (":") == string::npos))
     return false;
@@ -211,15 +215,15 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
 	uristr << "@" << (*it)->get_host ();
 
 	uris.push_back (uristr.str ());
-	accounts.push_back ((*it)->get_name ());
+	accounts_list.push_back ((*it)->get_name ());
       }
     }
   } else {
     uris.push_back (uri);
-    accounts.push_back ("");
+    accounts_list.push_back ("");
   }
 
-  std::list<std::string>::iterator ita = accounts.begin ();
+  std::list<std::string>::iterator ita = accounts_list.begin ();
   for (std::list<std::string>::iterator it = uris.begin ();
        it != uris.end ();
        it++) {
@@ -245,7 +249,7 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
     ita++;
   }
 
-  ita = accounts.begin ();
+  ita = accounts_list.begin ();
   for (std::list<std::string>::iterator it = uris.begin ();
        it != uris.end ();
        it++) {
@@ -269,94 +273,76 @@ Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
 
 
 void
-Opal::Sip::EndPoint::fetch (const std::string _uri)
+Opal::Sip::EndPoint::fetch (const std::string uri)
 {
-  PWaitAndSignal mut(listsMutex);
-  std::string::size_type loc = _uri.find ("@", 0);
-  std::string domain;
-
-  if (loc != string::npos)
-    domain = _uri.substr (loc+1);
-
-  // It is not in the list of uris for which a subscribe is active
-  if (std::find (subscribed_uris.begin (), subscribed_uris.end (), _uri) == subscribed_uris.end ()) {
-
-    // The account is active
-    if (std::find (active_domains.begin (), active_domains.end (), domain) != active_domains.end ()) {
-
-      Subscribe (SIPSubscribe::Presence, 300, PString (_uri.c_str ()));
-      Subscribe (SIPSubscribe::Dialog, 300, PString (_uri.c_str ()));
-      subscribed_uris.push_back (_uri);
-    }
-    else {
-
-      to_subscribe_uris.push_back (_uri);
-    }
-  }
+  Subscribe (SIPSubscribe::Presence, 300, uri);
+  Subscribe (SIPSubscribe::Dialog, 300, uri);
 }
 
 
 void
 Opal::Sip::EndPoint::unfetch (const std::string uri)
 {
-  PWaitAndSignal mut(listsMutex);
-  if (std::find (subscribed_uris.begin (), subscribed_uris.end (), uri) != subscribed_uris.end ()) {
-
-    Subscribe (SIPSubscribe::Presence, 0, PString (uri.c_str ()));
-    Subscribe (SIPSubscribe::Dialog, 0, PString (uri.c_str ()));
-    subscribed_uris.remove (uri);
-  }
+  Subscribe (SIPSubscribe::Presence, 0, uri);
+  Subscribe (SIPSubscribe::Dialog, 0, uri);
 }
 
 
 void
 Opal::Sip::EndPoint::publish (const Ekiga::PersonalDetails & details)
 {
-  PWaitAndSignal mut(listsMutex);
+  std::map<std::string, PString> publishing;
   std::string hostname = (const char *) PIPSocket::GetHostName ();
   std::string presence = ((Ekiga::PersonalDetails &) (details)).get_presence ();
   std::string status = ((Ekiga::PersonalDetails &) (details)).get_status ();
 
-  for (std::list<std::string>::iterator it = aors.begin ();
-       it != aors.end ();
-       it++) {
-    std::string to = it->substr (4);
-    PString data;
-    data += "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\r\n";
+  for (PSafePtr<SIPHandler> handler = activeSIPHandlers.GetFirstHandler(); handler != NULL; ++handler) {
 
-    data += "<presence xmlns=\"urn:ietf:params:xml:ns:pidf\" entity=\"pres:";
-    data += to;
-    data += "\">\r\n";
+    if (handler->GetMethod() == SIP_PDU::Method_REGISTER) {
 
-    data += "<tuple id=\"";
-    data += to;
-    data += "_on_";
-    data += hostname;
-    data += "\">\r\n";
+      PString data;
+      std::string to = handler->GetAddressOfRecord ().AsString ().Mid (4);
+      data += "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\r\n";
 
-    data += "<note>";
-    data += presence.c_str ();
-    if (!status.empty ()) {
-      data += " - ";
-      data += status.c_str ();
+      data += "<presence xmlns=\"urn:ietf:params:xml:ns:pidf\" entity=\"pres:";
+      data += to;
+      data += "\">\r\n";
+
+      data += "<tuple id=\"sip:";
+      data += to;
+      data += "_on_";
+      data += hostname;
+      data += "\">\r\n";
+
+      data += "<note>";
+      data += presence.c_str ();
+      if (!status.empty ()) {
+        data += " - ";
+        data += status.c_str ();
+      }
+      data += "</note>\r\n";
+
+      data += "<status>\r\n";
+      data += "<basic>";
+      data += "open";
+      data += "</basic>\r\n";
+      data += "</status>\r\n";
+
+      data += "<contact priority=\"1\">";
+      data += to; 
+      data += "</contact>\r\n";
+
+      data += "</tuple>\r\n";
+      data += "</presence>\r\n";
+
+      publishing[to]=data;
     }
-    data += "</note>\r\n";
-
-    data += "<status>\r\n";
-    data += "<basic>";
-    data += "open";
-    data += "</basic>\r\n";
-    data += "</status>\r\n";
-
-    data += "<contact priority=\"1\">sip:";
-    data += to;
-    data += "</contact>\r\n";
-
-    data += "</tuple>\r\n";
-    data += "</presence>\r\n";
-
-    Publish (to, data, 500); // TODO: allow to change the 500
   }
+
+  for (std::map<std::string, PString>::const_iterator iter = publishing.begin ();
+       iter != publishing.end ();
+       ++iter)
+    Publish (iter->first, iter->second, 500); // TODO: allow to change the 500
 }
 
 
@@ -574,9 +560,9 @@ Opal::Sip::EndPoint::Register (const std::string username,
 			       const std::string auth_username,
 			       const std::string password,
 			       bool is_enabled,
+			       bool is_limited,
 			       unsigned timeout)
 {
-  PWaitAndSignal mut(listsMutex);
   PString _aor;
   std::stringstream aor;
   std::string host(host_);
@@ -591,21 +577,15 @@ Opal::Sip::EndPoint::Register (const std::string username,
 
   SIPRegister::Params params;
   params.m_addressOfRecord = aor.str ();
-  params.m_registrarAddress = host;
+  params.m_registrarAddress = host_;
+  if (is_limited)
+    params.m_compatibility = SIPRegister::e_CannotRegisterMultipleContacts;
   params.m_authID = auth_username;
   params.m_password = password;
   params.m_expire = is_enabled ? timeout : 0;
   params.m_minRetryTime = 0;
   params.m_maxRetryTime = 0;
 
-  // Update the list of active domains
-  std::string domain = Opal::Sip::EndPoint::get_aor_domain (aor.str ());
-  bool found = (std::find (active_domains.begin (), active_domains.end (), domain) != active_domains.end ());
-  if (is_enabled && !found)
-    active_domains.push_back (domain);
-  else if (!is_enabled && found)
-    active_domains.remove (domain);
-
   // Register the given aor to the give registrar
   if (!SIPEndPoint::Register (params, _aor))
     OnRegistrationFailed (aor.str (), SIP_PDU::MaxStatusCode, is_enabled);
@@ -616,11 +596,7 @@ void
 Opal::Sip::EndPoint::OnRegistered (const PString & _aor,
 				   bool was_registering)
 {
-  PWaitAndSignal mut(listsMutex);
   std::string aor = (const char *) _aor;
-  std::string::size_type found;
-  std::string::size_type loc = aor.find ("@", 0);
-  std::string server;
   std::stringstream strm;
 
   if (aor.find (uri_prefix) == std::string::npos)
@@ -628,66 +604,12 @@ Opal::Sip::EndPoint::OnRegistered (const PString & _aor,
   else
     strm << aor;
 
-  std::list<std::string>::iterator it = find (aors.begin (), aors.end (), aor);
-
-  if (was_registering) {
-
-    if (it == aors.end ())
-      aors.push_back (strm.str ());
-  }
-  else {
-
-    if (it != aors.end ())
-      aors.remove (strm.str ());
-  }
-
-  if (loc != string::npos) {
-
-    server = get_aor_domain (aor);
-    if (server.empty ())
-      return;
-
-    if (was_registering) {
-      for (std::list<std::string>::const_iterator iter = to_subscribe_uris.begin ();
-           iter != to_subscribe_uris.end () ; ) {
-
-        found = (*iter).find (server, 0);
-        if (found != string::npos) {
-
-          Subscribe (SIPSubscribe::Presence, 300, PString ((*iter).c_str ()));
-          Subscribe (SIPSubscribe::Dialog, 300, PString ((*iter).c_str ()));
-          subscribed_uris.push_back (*iter);
-          to_subscribe_uris.remove (*iter++);
-        }
-        else
-          ++iter;
-      }
-    }
-    else {
-      for (std::list<std::string>::const_iterator iter = subscribed_uris.begin ();
-           iter != subscribed_uris.end () ; ) {
-
-        found = (*iter).find (server, 0);
-        if (found != string::npos) {
-
-          Unsubscribe (SIPSubscribe::Presence, PString ((*iter).c_str ()));
-          Unsubscribe (SIPSubscribe::Dialog, PString ((*iter).c_str ()));
-          to_subscribe_uris.push_back (*iter);
-          subscribed_uris.remove (*iter++);
-        }
-        else
-          iter++;
-      }
-    }
-  }
-
   /* Subscribe for MWI */
   if (!IsSubscribed (SIPSubscribe::MessageSummary, aor))
     Subscribe (SIPSubscribe::MessageSummary, 3600, aor);
 
   /* Signal */
-  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this,
-							  &Opal::Sip::EndPoint::registration_event_in_main),
+  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::registration_event_in_main),
 					   strm.str (),
 					   was_registering ? Ekiga::Account::Registered : Ekiga::Account::Unregistered,
 					   std::string ()));
@@ -944,7 +866,7 @@ Opal::Sip::EndPoint::OnMWIReceived (const PString & party,
     mwi = "0/0";
 
   /* Signal */
-  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::mwi_received_in_main), party, info));
+  Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::mwi_received_in_main), party, mwi));
 }
 
 
@@ -1034,43 +956,16 @@ Opal::Sip::EndPoint::OnMessageFailed (const SIPURL & messageUrl,
 
 
 SIPURL
-Opal::Sip::EndPoint::GetRegisteredPartyName (const SIPURL & host,
+Opal::Sip::EndPoint::GetRegisteredPartyName (const SIPURL & aor,
 					     const OpalTransport & transport)
 {
-  PString local_address;
-  PIPSocket::Address address;
-  WORD port;
-  PString url;
-  SIPURL registration_address;
+  PWaitAndSignal m(aorMutex);
+  std::string local_aor = accounts[(const char*) aor.GetHostName ()];
 
-  /* If we are registered to an account corresponding to host, use it.
-   */
-  PSafePtr<SIPHandler> info = activeSIPHandlers.FindSIPHandlerByDomain(host.GetHostName (), SIP_PDU::Method_REGISTER, PSafeReadOnly);
-  if (info != NULL) {
+  if (!local_aor.empty ())
+    return local_aor.c_str ();
 
-    return SIPURL ("\"" + GetDefaultDisplayName () + "\" <" + info->GetAddressOfRecord ().AsString () + ">");
-  }
-  else {
-
-    /* If we are not registered to host,
-     * then use the default account as outgoing identity.
-     * If we are exchanging messages with a peer on our network,
-     * then do not use the default account as outgoing identity.
-     */
-    if (host.GetHostAddress ().GetIpAndPort (address, port) && !manager.IsLocalAddress (address)) {
-
-      /* FIXME: this is the only place where we use the bank in a thread
-       * can't we just return GetDefaultDisplayName () ?
-       */
-      AccountPtr account = bank->find_account ("Ekiga.net");
-
-      if (account)
-        return SIPURL ("\"" + GetDefaultDisplayName () + "\" <" + PString(account->get_aor ()) + ">");
-    }
-  }
-
-  /* As a last resort, ie not registered to host, no default account or
-   * dialog with a local peer, then use the local address
+  /* As a last resort, use the local address
    */
   return GetDefaultRegisteredPartyName (transport);
 }
@@ -1088,12 +983,15 @@ Opal::Sip::EndPoint::OnPresenceInfoReceived (const PString & user,
   std::string presence = "unknown";
   std::string status;
 
-  if (!basic.IsEmpty () && !note.IsEmpty ()) {
+  if (!basic.IsEmpty ()) {
 
     if (b.Find ("Open") != P_MAX_INDEX)
       presence = "online";
     else
       presence = "offline";
+  }
+
+  if (!note.IsEmpty ()) {
 
     if (s.Find ("Away") != P_MAX_INDEX)
       presence = "away";
@@ -1199,6 +1097,26 @@ void Opal::Sip::EndPoint::on_transfer (std::string uri)
       connection->TransferConnection (uri);
 }
 
+
+void
+Opal::Sip::EndPoint::on_bank_updated (Ekiga::AccountPtr /*account*/)
+{
+  bank->visit_accounts (sigc::mem_fun (this, &Opal::Sip::EndPoint::visit_accounts));
+}
+
+
+bool
+Opal::Sip::EndPoint::visit_accounts (Ekiga::AccountPtr account_)
+{
+  Opal::AccountPtr account = account_;
+
+  PWaitAndSignal m(aorMutex);
+  accounts[account->get_host ()] = account->get_aor ();
+
+  return true;
+}
+
+
 void
 Opal::Sip::EndPoint::registration_event_in_main (const std::string aor,
 						 Ekiga::Account::RegistrationState state,
@@ -1206,10 +1124,8 @@ Opal::Sip::EndPoint::registration_event_in_main (const std::string aor,
 {
   AccountPtr account = bank->find_account (aor);
 
-  if (account) {
-
+  if (account) 
     account->registration_event.emit (state, msg);
-  }
 }
 
 
