@@ -40,8 +40,9 @@
 
 #include "gmconf.h"
 #include "codec-description.h"
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
+#include <sstream>
 
 /* Columns for the codecs page */
 enum {
@@ -213,9 +214,9 @@ codec_toggled_cb (G_GNUC_UNUSED GtkCellRendererToggle *cell,
   /* Update the gmconf key */
   codecs_data = codecs_box_to_gm_conf_list (self);
   if (self->priv->type == Ekiga::Call::Audio)
-    gm_conf_set_string_list ("/apps/ekiga/codecs/audio/media_list", codecs_data);
+    gm_conf_set_string_list ("/apps/" PACKAGE_NAME "/codecs/audio/media_list", codecs_data);
   else if (self->priv->type == Ekiga::Call::Video)
-    gm_conf_set_string_list ("/apps/ekiga/codecs/video/media_list", codecs_data);
+    gm_conf_set_string_list ("/apps/" PACKAGE_NAME "/codecs/video/media_list", codecs_data);
   g_slist_foreach (codecs_data, (GFunc) g_free, NULL);
   g_slist_free (codecs_data);
 }
@@ -275,9 +276,9 @@ codec_moved_cb (GtkWidget *widget,
   /* Update the gmconf key */
   codecs_data = codecs_box_to_gm_conf_list (self);
   if (self->priv->type == Ekiga::Call::Audio)
-    gm_conf_set_string_list ("/apps/ekiga/codecs/audio/media_list", codecs_data);
+    gm_conf_set_string_list ("/apps/" PACKAGE_NAME "/codecs/audio/media_list", codecs_data);
   else if (self->priv->type == Ekiga::Call::Video)
-    gm_conf_set_string_list ("/apps/ekiga/codecs/video/media_list", codecs_data);
+    gm_conf_set_string_list ("/apps/" PACKAGE_NAME "/codecs/video/media_list", codecs_data);
   g_slist_foreach (codecs_data, (GFunc) g_free, NULL);
   g_slist_free (codecs_data);
 }
@@ -435,7 +436,7 @@ codecs_box_init (CodecsBox *self)
                                                      COLUMN_CODEC_NAME,
                                                      NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (self->priv->codecs_list), column);
-  g_object_set (G_OBJECT (renderer), "weight", "bold", NULL);
+  g_object_set (G_OBJECT (renderer), "weight", PANGO_WEIGHT_BOLD, NULL);
 
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (NULL,
@@ -563,9 +564,9 @@ codecs_box_set_property (GObject *obj,
   }
 
   if (self->priv->type == Ekiga::Call::Audio)
-    list = gm_conf_get_string_list ("/apps/ekiga/codecs/audio/media_list");
+    list = gm_conf_get_string_list ("/apps/" PACKAGE_NAME "/codecs/audio/media_list");
   else if (self->priv->type == Ekiga::Call::Video)
-    list = gm_conf_get_string_list ("/apps/ekiga/codecs/video/media_list");
+    list = gm_conf_get_string_list ("/apps/" PACKAGE_NAME "/codecs/video/media_list");
 
   codecs_box_set_codecs (self, list);
 
@@ -573,9 +574,9 @@ codecs_box_set_property (GObject *obj,
   g_slist_free (list);
 
   if (self->priv->type == Ekiga::Call::Audio)
-    gm_conf_notifier_add ("/apps/ekiga/codecs/audio/media_list", codecs_list_changed_nt, GTK_WIDGET (self));
+    gm_conf_notifier_add ("/apps/" PACKAGE_NAME "/codecs/audio/media_list", codecs_list_changed_nt, GTK_WIDGET (self));
   else
-    gm_conf_notifier_add ("/apps/ekiga/codecs/video/media_list", codecs_list_changed_nt, GTK_WIDGET (self));
+    gm_conf_notifier_add ("/apps/" PACKAGE_NAME "/codecs/video/media_list", codecs_list_changed_nt, GTK_WIDGET (self));
 }
 
 
