@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
  *   begin                : Thu Nov 22 2001
  *   copyright            : (C) 2000-2006 by Damien Sandras
  *   description          : This file contains miscellaneous functions.
- *   Additional Code      : De Michele Cristiano, Miguel Rodrguez 
+ *   Additional Code      : De Michele Cristiano, Miguel Rodríguez
  *
  */
 
@@ -46,13 +46,45 @@
 #include "gmdialog.h"
 #include "gmconf.h"
 
-
-
 #ifndef WIN32
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
 #endif
 
+#include <glib/gi18n.h>
+
+
+/* return the default audio device name */
+const gchar *get_default_audio_device_name (void)
+{
+#ifdef WIN32
+  return "Default (PTLIB/WindowsMultimedia)";
+#else
+  return "Default (PTLIB/ALSA)";
+#endif
+}
+
+/* return the default video name from the list of existing devices */
+const gchar *get_default_video_device_name (const gchar * const *options)
+{
+#ifdef WIN32
+  /* look for the entry containing "PTLIB/DirectShow" or "PTLIB/VideoForWindows" */
+  for (int i = 0; options[i]; i++)
+    if (g_strrstr (options[i], "PTLIB/DirectShow")
+        || g_strrstr (options[i], "PTLIB/VideoForWindows"))
+      return options[i];
+#else
+  /* look for the entry containing "PTLIB/V4L2", otherwise "PTLIB/V4L" */
+  for (int i = 0; options[i]; i++)
+    if (g_strrstr (options[i], "PTLIB/V4L2"))
+      return options[i];
+  for (int i = 0; options[i]; i++)
+    if (g_strrstr (options[i], "PTLIB/V4L"))
+      return options[i];
+#endif
+  return NULL;  // not found
+}
+
 
 /* The functions */
 GtkWidget *
@@ -76,63 +108,6 @@ gnomemeeting_button_new (const char *lbl,
 }
 
 
-
-/* This function overrides from a pwlib function */
-#ifndef STATIC_LIBS_USED
-static gboolean
-assert_error_msg (gpointer data)
-{
-  GtkWidget *main_window = NULL;
-
-  main_window = GnomeMeeting::Process ()->GetMainWindow ();
-
-  
-  //gdk_threads_enter ();
-  std::cout << "FIXME" << std::endl << std::flush;
-  //FIXME Should use a signal in the runtime.
-  gnomemeeting_error_dialog (GTK_WINDOW (main_window), 
-			     _("Error"),
-			     "%s", (gchar *) data);
-  //gdk_threads_leave ();
-
-  return FALSE;
-}
-
-
-void 
-PAssertFunc (G_GNUC_UNUSED const char *file,
-	     G_GNUC_UNUSED int line,
-	     G_GNUC_UNUSED const char *className,
-	     const char *msg)
-{
-  g_idle_add_full (G_PRIORITY_HIGH, assert_error_msg, g_strdup (msg), g_free);
-}
-#endif
-
-
-
-PString
-gnomemeeting_pstring_cut (PString s)
-{
-  PString s2 = s;
-
-  if (s.IsEmpty ())
-    return s2;
-
-  PINDEX bracket = s2.Find('[');                                          
-                                                                               
-  if (bracket != P_MAX_INDEX)                                                
-    s2 = s2.Left (bracket);                                            
-
-  bracket = s2.Find('(');                                                 
-                                                                               
-  if (bracket != P_MAX_INDEX)                                                
-    s2 = s2.Left (bracket);     
-
-  return s2.Trim ();
-}
-    
-
 /* Stolen from GDK */
 #ifndef WIN32
 static void
@@ -182,7 +157,12 @@ gdk_window_set_always_on_top (GdkWindow *window,
 gboolean 
 gnomemeeting_window_is_visible (GtkWidget *w)
 {
-  return (GTK_WIDGET_VISIBLE (w) && !(gdk_window_get_state (GDK_WINDOW (w->window)) & GDK_WINDOW_STATE_ICONIFIED));
+#if GTK_CHECK_VERSION(2,18,0)
+  return (gtk_widget_get_visible (GTK_WIDGET (w))
+#else
+  return (GTK_WIDGET_VISIBLE (w)
+#endif
+          && !(gdk_window_get_state (GDK_WINDOW (w->window)) & GDK_WINDOW_STATE_ICONIFIED));
 }
 
 
