@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,7 +40,21 @@
 #ifndef _MISC_H_
 #define _MISC_H_
 
-#include "common.h"
+#include <gtk/gtk.h>
+
+
+/* DESCRIPTION  :  /
+ * BEHAVIOR     :  /
+ * PRE          :  /
+ */
+const gchar *get_default_audio_device_name (void);
+
+
+/* DESCRIPTION  :  /
+ * BEHAVIOR     :  /
+ * PRE          :  /
+ */
+const gchar *get_default_video_device_name (const gchar * const *options);
 
 
 /* DESCRIPTION  :  / 
@@ -53,15 +67,6 @@ gnomemeeting_button_new (const char *label,
 			 GtkWidget *pixmap);
 
 
-/* DESCRIPTION   :  /
- * BEHAVIOR      : Takes a PString and returns the Left part before a [ or a (.
- * PRE           : An non-empty PString.
- */
-PString 
-gnomemeeting_pstring_cut (PString s);
-
-
-
 void gdk_window_set_always_on_top (GdkWindow *window, 
 				   gboolean enable);
 
