@@ -235,7 +235,7 @@ statusicon_get_type ()
  * Callbacks
  */
 static void
-show_popup_menu_cb (G_GNUC_UNUSED GtkStatusIcon *icon,
+show_popup_menu_cb (GtkStatusIcon *icon,
                     guint button,
                     guint activate_time,
                     gpointer data)
@@ -245,7 +245,8 @@ show_popup_menu_cb (G_GNUC_UNUSED GtkStatusIcon *icon,
   popup = GTK_WIDGET (data);
 
   gtk_menu_popup (GTK_MENU (popup),
-                  NULL, NULL, NULL, NULL,
+                  NULL, NULL, 
+                  (GtkMenuPositionFunc)gtk_status_icon_position_menu, icon,
                   button, activate_time);
 }
 
@@ -263,7 +264,11 @@ statusicon_activated_cb (G_GNUC_UNUSED GtkStatusIcon *icon,
     window = GnomeMeeting::Process ()->GetMainWindow (); //FIXME
 
     // FIXME when the main window becomes a gobject
-    if (!(GTK_WIDGET_VISIBLE (window) 
+#if GTK_CHECK_VERSION(2,18,0)
+    if (!(gtk_widget_get_visible (GTK_WIDGET (window))
+#else
+    if (!(GTK_WIDGET_VISIBLE (window)
+#endif
           && !(gdk_window_get_state (GDK_WINDOW (window->window)) & GDK_WINDOW_STATE_ICONIFIED))) {
       gtk_widget_show (window);
     }
@@ -306,13 +311,20 @@ unread_count_cb (G_GNUC_UNUSED GtkWidget *widget,
 					 "You have %d messages",
 					 messages), messages);
 
+#if GTK_CHECK_VERSION(2,16,0)
+    gtk_status_icon_set_tooltip_text (GTK_STATUS_ICON (self), message);
+#else
     gtk_status_icon_set_tooltip (GTK_STATUS_ICON (self), message);
+#endif
 
     g_free (message);
   }
   else {
-
+#if GTK_CHECK_VERSION(2,16,0)
+    gtk_status_icon_set_tooltip_text (GTK_STATUS_ICON (self), NULL);
+#else
     gtk_status_icon_set_tooltip (GTK_STATUS_ICON (self), NULL);
+#endif
   }
 
   self->priv->unread_messages = (messages > 0);
